==> lifeeasy-1.0.tar.gz: lifeeasy-1.0/setup.py <==
#from distutils.core import setup
from setuptools import setup

# read the contents of the README file
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
  name = 'lifeeasy',         # How you named your package folder (MyLib)
  packages = ['lifeeasy'],   # Chose the same as "name"
  version = '1.0',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A simple python toolbox.',   # Give a short description about your library
  author = 'Anime no Sekai',                   # Type in your name
  author_email = 'niichannomail@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/user/Animenosekai/lifeeasy',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Animenosekai/lifeeasy/archive/v1.0.tar.gz',    # Archive link
  keywords = ['tools', 'one-line', 'easy', 'lifeeasy', 'library', 'toolbox', 'developer'],   # Keywords that define your package best
  install_requires=[
    "requests",
    "psutil"            # Dependencies
  ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
  long_description=long_description,
  long_description_content_type='text/markdown'
)

==> lifeeasy-1.1.tar.gz: lifeeasy-1.1/setup.py <==
#from distutils.core import setup
from setuptools import setup

# read the contents of the README file
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
  name = 'lifeeasy',         # How you named your package folder (MyLib)
  packages = ['lifeeasy'],   # Chose the same as "name"
  version = '1.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A simple python toolbox.',   # Give a short description about your library
  author = 'Anime no Sekai',                   # Type in your name
  author_email = 'niichannomail@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Animenosekai/lifeeasy',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Animenosekai/lifeeasy/archive/v1.0.tar.gz',    # Archive link
  keywords = ['tools', 'one-line', 'easy', 'lifeeasy', 'library', 'toolbox', 'developer'],   # Keywords that define your package best
  install_requires=[
    "requests",
    "psutil"            # Dependencies
  ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
  long_description=long_description,
  long_description_content_type='text/markdown'
)
